@@ -46,6 +46,7 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/default_ntp_server').with_value('<SERVICE DEFAULT>') }
     end
 
@@ -62,6 +63,7 @@ describe 'sahara' do
         :memcached_servers     => '1.1.1.1:11211',
         :plugins               => ['plugin1', 'plugin2'],
         :default_transport_url => 'rabbit://guest2:pass@localhost2:5673',
+        :rpc_response_timeout  => '120',
         :control_exchange      => 'openstack',
         :default_ntp_server    => 'pool.ntp.org',
       }
@@ -78,6 +80,7 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('1.1.1.1:11211') }
       it { is_expected.to contain_sahara_config('DEFAULT/plugins').with_value('plugin1,plugin2') }
       it { is_expected.to contain_sahara_config('DEFAULT/transport_url').with_value('rabbit://guest2:pass@localhost2:5673') }
+      it { is_expected.to contain_sahara_config('DEFAULT/rpc_response_timeout').with_value('120') }
       it { is_expected.to contain_sahara_config('DEFAULT/control_exchange').with_value('openstack') }
       it { is_expected.to contain_sahara_config('DEFAULT/default_ntp_server').with_value('pool.ntp.org') }
     end
